@@ -8,7 +8,12 @@ from api_pagador import settings, urls
 
 sys.path.append('./')
 urls.registrar()
-parent_app = DispatcherMiddleware(app_pagador, {})
+
+
+def define_no_settings(variavel, valor):
+    if not hasattr(settings, variavel.upper()):
+        setattr(settings, variavel.upper(), valor)
 
 if __name__ == "__main__":
+    parent_app = DispatcherMiddleware(app_pagador, {})
     run_simple(settings.HOST, settings.PORT, parent_app)
